from django.shortcuts import render, get_object_or_404
from django.http import HttpResponse, Http404
from django.views.decorators.http import require_safe

from pgp import models

class HttpNotImplementedError(HttpResponse):
    status_code = 501

@require_safe
def lookup(request):
    op = request.GET.get('op', None)
    search = request.GET.get('search', None).lower()
    
    if op not in ["get"]:
        return HttpNotImplementedError("Not implemented")

    if search.startswith("0x"):
        search = search[2:]

    key = get_object_or_404(models.PublicKey, keyid__endswith=search)
    if not request.user.has_perm("pgp.view_publickey", key):
        raise Http404()

    response = HttpResponse(key.armor, content_type="application/pgp-keys")
    response["Access-Control-Allow-Origin"] = "*"
    response["Access-Control-Allow-Methods"] = "GET, OPTIONS, HEAD"
    return response
